@@ -3,7 +3,7 @@
 # =========================================================================
 #   Program:   S1Processor
 #
-#   Copyright 2017-2021 (c) CESBIO. All rights reserved.
+#   Copyright 2017-2021 (c) CNES. All rights reserved.
 #
 #   This file is part of S1Tiling project
 #       https://gitlab.orfeo-toolbox.org/s1-tiling/s1tiling
@@ -35,6 +35,10 @@ class S1DateAcquisition:
         self.manifest = manifest
         self.image_filenames_list = image_filenames_list
 
+
+    def __repr__(self):
+        return "S1DateAcquisition('%s', %s)" % (self.manifest, self.image_filenames_list)
+
     def get_manifest(self):
         """ Get the manifest file """
         return self.manifest
